.. _api:

API
===
.. automodule:: stella
    :members:

.. autoclass:: FlareDataSet
    :members:

.. autoclass:: ConvNN
    :members:

.. autoclass:: FitFlares
    :members:

.. autoclass:: MeasureProt
    :members:

.. autoclass:: Visualize
    :members:
